## Version 0.15.3

This release includes minor updates and maintenance improvements.

### New Features

- Added release notes for the previous version 0.15.2 (967edf) (github-actions)

### Bug Fixes

- None

### Deprecations

- None

Please note that the commit log provided does not detail specific new features, bug fixes, or deprecations beyond the addition of release notes. For a more detailed list of changes, please refer to the full commit history or the detailed release notes for version 0.15.2.
